#
# spec file for package translate-toolkit
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           translate-toolkit
Version:        1.13.0
Release:        3.24
Summary:        Tools and API to assist with translation and software localization
License:        GPL-2.0+
Group:          Development/Tools/Other
Url:            http://toolkit.translatehouse.org/
Source:         https://github.com/translate/translate/releases/download/%{version}/%{name}-%{version}.tar.bz2
BuildRequires:  fdupes
BuildRequires:  gettext-runtime
BuildRequires:  iso-codes
# The following are needed for man page and docs generation
BuildRequires:  python-Babel
BuildRequires:  python-Levenshtein
BuildRequires:  python-Sphinx
BuildRequires:  python-beautifulsoup4
BuildRequires:  python-devel
BuildRequires:  python-iniparse
BuildRequires:  python-lxml
BuildRequires:  python-lxml-doc
BuildRequires:  python-pyenchant
BuildRequires:  python-pytest
BuildRequires:  python-utidy
BuildRequires:  python-xml
Requires:       gettext-runtime
Requires:       python-lxml
Requires:       python-pyenchant
Requires:       python-six
# The following are for the full experience of translate-toolkit
Recommends:     gaupol
Recommends:     iso-codes
Recommends:     python-Levenshtein
Recommends:     python-aeidon
Recommends:     python-iniparse
Recommends:     python-utidy
Recommends:     vobject
Provides:       python-translate-toolkit = %{version}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch
%py_requires

%description
The Translate Toolkit is a set of software and documentation designed to help
make the lives of localizers both more productive and less frustrating.

The software includes programs to convert localization formats to the common
PO, and emerging XLIFF format.  There are also programs to check and manage PO
and XLIFF files.  Online documentation includes guides on using the tools,
running a localization project and how to localize various projects from
OpenOffice.org to Mozilla.

At its core the software contains a set of classes for handling various
localization storage formats: DTD, properties, OpenOffice.org GSI/SDF,
CSV, MO, Qt .ts, TMX, TBX, WordFast txt, Gettext .mo, Windows RC, and
of course PO and XLIFF.  It also provides scripts to convert between
these formats.

Also part of the Toolkit are Python programs to create word counts, merge
translations and perform various checks on translation files.

%package devel-doc
Summary:        Tools and API to assist with translation and software localization
Group:          Development/Libraries/Python
Requires:       %{name} = %{version}
Provides:       %{name}-devel = %{version}
Obsoletes:      %{name}-devel < %{version}
BuildArch:      noarch

%description devel-doc
The %{name}-devel-doc package contains Translate Toolkit API documentation for developers wishing to build new tools for the
toolkit or to use the libraries in other localization tools.

%prep
%setup -q
sed -i 296"s|'share'|'translate/share'|" setup.py
# fix for bnc#750652 - remove Apache-2.0 file - difflib is the fallback solution
rm translate/misc/diff_match_patch.py*

#Fix for shebang errors:
for lib in translate/{*.py,*/*.py,*/*/*.py}; do
 sed -i '\|%{_bindir}/env |d' $lib
done

#fix wrong perms
chmod a-x docs/_build/html/_static/font/*.* docs/_themes/sphinx-bootstrap/static/font/*.*
#fix line terminators in jquery.js
sed -i 's/\r//' docs/_build/html/_static/jquery.js
sed -i 's/\r//' docs/_themes/sphinx-bootstrap/static/jquery.js

%build
python setup.py build
pushd docs
make %{?_smp_mflags} html man
gzip -9 _build/man/*.1
#no hidden files
find _build -name '.?*' -exec rm '{}' \+
popd

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}

# create manpages
mkdir -p %{buildroot}/%{_mandir}/man1
for program in %{buildroot}/%{_bindir}/*; do
    case $(basename $program) in
      pocompendium|poen|pomigrate2|popuretext|poreencode|posplit|pocount|poglossary|lookupclient.py|tmserver|build_tmdb)
        ;;
      *)
        LC_ALL=C PYTHONPATH=. $program --manpage \
          >  %{buildroot}/%{_mandir}/man1/$(basename $program).1 \
          || rm -f %{buildroot}/%{_mandir}/man1/$(basename $program).1
        ;;
    esac
done
install -m 644 docs/_build/man/*.gz %{buildroot}/%{_mandir}/man1/

# move documentation files to datadir
install -d -m 755 %{buildroot}%{_defaultdocdir}/%{name}
mv %{buildroot}%{python_sitelib}/translate/docs/_build/html %{buildroot}%{_defaultdocdir}/%{name}
rm -rf %{buildroot}%{python_sitelib}/translate/docs
rm -rf %{buildroot}/home/abuild/.local/lib/python%{py_ver}/site-packages/

# create symlinks for man pages
%fdupes -s %{buildroot}/%{_mandir}
# create hardlinks for the rest
%fdupes %{buildroot}

%files
%defattr(-,root,root)
%exclude %{_defaultdocdir}/%{name}/html/api
%exclude %{_defaultdocdir}/%{name}/html/_sources
%doc COPYING README.rst
%{_bindir}/*
%{_mandir}/man1/*
%{python_sitelib}/translate
%{python_sitelib}/translate_toolkit-%{version}-py%{py_ver}.egg-info

%files devel-doc
%defattr(-,root,root)
%doc %{_defaultdocdir}/%{name}/html/api
%doc %{_defaultdocdir}/%{name}/html/_sources

%changelog
* Wed Jul 29 2015 dimstar@opensuse.org
- Require python-six: translate/misc/quote.py depends on it.
* Wed Jul 15 2015 mcihar@suse.cz
- use spec-cleaner to sort dependencies
* Wed Jul 15 2015 mcihar@suse.cz
- make dependency on several optional features only recommended: vobject,
  Levenshtein, aeidon, iniparse
- remove not needed xapian build dependency
- remove not used simplejson from build/runtime dependencies
* Fri May 15 2015 elchevive@opensuse.org
- updated to version 1.13.0
- updated Source URL and run spec-cleaner
  Major changes
  New converters for IDML format
  Support for new .Net Resource (.resx) format
  Extensive cleanup on ODF converters
  New quality checks
    Some bugfixes and improvements
* Thu Nov  6 2014 mcihar@suse.cz
- remove not needed gaupol build dependency
* Tue Aug 12 2014 elchevive@opensuse.org
- updated to version 1.12.0
  Major changes
  Properties and DTD formats fix a number of issues
  Massive code cleanup looking forward Python 3 compatibility
  Important changes in development process to ease testing
* Thu Jan 30 2014 elchevive@opensuse.org
- updated to version 1.11.0
  Major changes:
  The PO format now matches Gettext more closely
  PHP format adds a number of new features
  Support for Python 2.5 has been dropped
* Sun Jul 14 2013 elchevive@opensuse.org
- add 2 missing BuildRequires (python-Levenshtein and change
  python-aeidon with gaupol)
* Fri Jun 28 2013 elchevive@opensuse.org
- Add python-{Levenshtein,aeidon} as Requires and remove again
  diff_match_patch as its not allowed on Factory (license issue)
* Tue Mar 26 2013 fa0sck@gmail.com
- New upstream version (1.10.0)
  * devel package renamed as devel-doc.
* Sat Jan 12 2013 dmitry.rojkov@gmail.com
- initial repackaging
* Tue Jun  5 2012 i@marguerite.su
- fix sles builds.
  * version tag for buildarch: noarch.
* Thu May 10 2012 elchevive@opensuse.org
- Remove psyco references as it is a dead project
* Thu Apr 19 2012 elchevive@opensuse.org
- Add Provides: python-translate-toolkit for compatibility with old packages
* Mon Mar 26 2012 elchevive@opensuse.org
- Cosmetic change in 'for' used to remove shebangs
* Tue Mar 20 2012 elchevive@opensuse.org
- Add proper specfile header as requested in sr#109322
* Wed Mar 14 2012 elchevive@opensuse.org
- Fix for bnc#750652 (remove Apache-2.0 file as the programa has a fallbak)
* Sun Feb 26 2012 elchevive@opensuse.org
- Add ifelse to python-pyenchant (new name for > 12.1)
* Wed Feb 22 2012 elchevive@opensuse.org
- Fix the non-executable-script warning
* Wed Apr 13 2011 elchevive@opensuse.org
- Updated to version 1.9.0
  Highlighted improvements
  - Faster terminology matching
  - Several small optimisations to performance and memory use
  - More advanced state support (visible in pocount and Virtaal 0.7)
  - Improved language detection models (+South African languages)
  - Improve handling of printf variable reordering [Jacques Beaurain]
  - Review of the wording of the messages of pofilter checks
  - Better sentence segmentation for some non-Latin languages
  - More supported formats for podebug
  - Extra options for pomerge, pogrep and po2oo/xliff2oo. The new pogrep options made this possible for GNOME: http://translate.org.za/blogs/friedel/en/content/better-lies-about-gnome-localisation
  Most relevant for Pootle:
  - Support for Xapian 1.2 (bug 1766) [Rimas Kudelis]
  - Work around some changes introduced in Django 1.2.5/1.3
  Format support:
  - Always use UNIX line endings for PO (even on Windows)
  - XLIFF and .ts files now shows "fuzzy" only the target present
  - Improved support for .ts comment as context (bug 1739)
  - Support for Java properties in UTF-8 encoding
  - More natural string ordering in json converter
  - Improved handling of trailing spaces in Mozilla DTD files
  - Removed unused support for _old_ KDE plurals in pocount
  ...and several small bugfixes
* Mon Dec 27 2010 elchevive@opensuse.org
- Removed 11.1 references and python- prefix
* Fri Nov 19 2010 elchevive@opensuse.org
- Updated to version 1.8.1
* Tue Aug 17 2010 elchevive@opensuse.org
- Updated to version 1.8.0
- Set Gaupol as Suggestion
* Wed May 12 2010 elchevive@opensuse.org
- Updated to version 1.7.0
* Fri Mar  5 2010 elchevive@opensuse.org
- Updated to version 1.6.0
- Added python-enchant as Requires
* Tue Feb 23 2010 elchevive@opensuse.org
- Rename -doc to -devel (as it is devel's docs)
- Added more requires (for ical2po, sub2po work)
- Remove duplicated docs in -devel
* Mon Feb 22 2010 elchevive@opensuse.org
- Package split (-doc) and manpages created (using Fedora's .spec)
* Tue Feb 16 2010 elchevive@opensuse.org
- Package updated to version 1.5.3
* Mon Jan 25 2010 elchevive@opensuse.org
- Added gettext-runtime as requirement
* Wed Jan 20 2010 elchevive@opensuse.org
- Added python-lxml as requirement
* Thu Jan 14 2010 elchevive@opensuse.org
- Initial release 1.5.2 - spec/rpmlint copyed from thomas-schaite repository
